@@ -191,7 +191,7 @@ bool SchemaModel::setData(const QModelIndex &index, const QVariant &value, int r
 
     m_product.setSchema(schema);
 
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
     return false;
 }
 
